@@ -566,13 +566,18 @@ class MBIODeviceDigimatSIO(MBIODevice):
 
 
 class SIOConfigurator(object):
-    def __init__(self, host, token=None):
+    def __init__(self, host, token=None, logger=None):
         self._host=host
         self._token=token or 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9'
+        self._logger=logger
         self._config={}
         self._updated=False
         self.reset()
 
+    @property
+    def logger(self):
+        return self._logger
+
     def reset(self):
         self._config={}
         self._updated=False
@@ -839,7 +844,7 @@ class SIOScanner(MBIONetworkScanner):
             self._token=token
 
     def configurator(self, host):
-        return SIOConfigurator(host, token=self._token)
+        return SIOConfigurator(host, token=self._token, logger=self.logger)
 
     def probe(self, host):
         hostid=None
